<?php
/**
*	@file app_functions.php
*	@brief Contains functions that are related to simulation view.
*/
require_once(dirname(__FILE__) . '/../general/functions.php');
require_once(dirname(__FILE__) . '/app_form_handling.php');
require_once(dirname(__FILE__) . '/app_index_form_handling.php');

/**
* Function to print out simulation HTML-page start with given title.
* @param string $title_code represents corresponding translation of a page title. Empty string by default.
* @return void
*/
function print_app_html_start($title_code='') {
	
	$title = '';
	if (empty($title_code)) {
		global $default_title;
		$title = $default_title;
	}
	else {
		$title = localize($title_code);
	}
	$config = Config::getInstance();
?>	
<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
<script type="text/javascript" src="<?php echo $config->baseurl; ?>js/jquery-1.8.3.min.js"></script>
<script type="text/javascript" src="<?php echo $config->baseurl; ?>js/jquery.scrollTo-1.4.3.1-min.js"></script>
<script type="text/javascript" src="<?php echo $config->baseurl; ?>js/jqModal.js"></script>
<script type="text/javascript" src="<?php echo $config->baseurl; ?>js/app.js"></script>
<script type="text/javascript" src="<?php echo $config->baseurl; ?>js/main.js"></script>
<link href='http://fonts.googleapis.com/css?family=Lobster+Two:700italic' rel='stylesheet' type='text/css'>
<link rel="stylesheet" type="text/css" href="<?php echo $config->baseurl; ?>css/main.css" />
<link rel="stylesheet" type="text/css" href="<?php echo $config->baseurl; ?>css/app.css" />
<link rel="stylesheet" type="text/css" href="<?php echo $config->baseurl; ?>css/jqModal.css" />
<title><?php echo $title; ?></title>
</head>
<body>
<script type="text/javascript">
<?php $config = Config::getInstance();
		echo ('window.baseurl = "' . $config->baseurl . '";' . PHP_EOL);
		echo("window.modRewrite = ");
		if (modRewriteEnabled()) {
			echo("true;");
		}
		else {
			echo("false;");
		}
?>
</script>
<?php
}

/**
* Function to print application header.
* @param array $stats Players current stats.
* @return void
*/
function print_app_header($stats) {
	
	global $language;
	$current_lang = $language;
	if (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	$visible_stats = array();
	if (isset($_SESSION['game']['visible_stats'])) {
		$visible_stats = $_SESSION['game']['visible_stats'];
	}
	?>
<div class="hidden_header">
<?php if (!empty($visible_stats)) : ?>
	<div id="hidden_header_columns" class="hidden_header_columns">
		<div class="hidden_header_left_column">
			<dl>
            <?php	$stat_names = array_keys($stats);
            		$stat_values = array_values($stats);
            			
            		foreach ($visible_stats as $stat) {
            				
							$index = array_search($stat, $stat_names);
							if ($index !== false) {
								$stat_temp = $stat_values[$index];
								if ($stat_temp[0] == '=') {
									$stat_temp = substr($stat_temp, 1);
								}
								echo('<dt>' . $stat. '</dt><dd>' . $stat_temp . '</dd>' . PHP_EOL);
							}
							else {
								echo('<dt>' . $stat. '</dt><dd>-</dd>' . PHP_EOL);
							}
            		}
            ?>
			</dl>
		</div>
		<div class="hidden_header_right_column">
<?php else: // no visible stats so no left column ?>	
	<div id="hidden_header_columns" class="hidden_header_columns_index">
		<div class="hidden_header_right_column hidden_header_right_column_index">  
<?php endif; ?>
			<dl>
				<?php print_login(); ?>
			</dl>    
		</div>
		<div style="clear:both;"></div>
	</div>
</div>
<?php
	$show_stats = true;
	if (empty($visible_stats)) $show_stats = false;
	print_app_header_lower_part($show_stats, true);
}

/**
 * Function to print lower part of application header
 */
function print_app_header_lower_part($show_stats, $clickable=true) {
	
	global $texts;
?>
<div class="hidden_header_background_repeat">
	
	<span class="hidden_header_show_hide hidden_header_logo">
		<?php if ($clickable) :?>
		<span id="app_header_your_life" class="left"><?php if ($show_stats) : echo($texts['your_life']); endif; ?></span>
		<span id="app_header_menu" class="right"><?php echo($texts['menu']); ?></span>
		<?php endif; ?>
	</span>
	
</div>
<div class="clear"></div>
<?php
}

/** 
* Function to print application index header.
* @return void
*/
function print_app_index_header($current_game) {
	$username = '';
	if (isset($_SESSION['user']['username'])) {
		$username = $_SESSION['user']['username'];
	}
	$isLogged = false;
	if (isset($_SESSION['isLogged']) && $_SESSION['isLogged']) {
		$isLogged = true;
	}	
	global $language;
	$current_lang = $language;
	if (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	$show_language_bar = 1;
	if (isset($current_game['multiple_languages'])) {
		$show_language_bar = $current_game['multiple_languages'];
	}
	$show_user_name = 1;
	if (isset($current_game['use_name'])) {
		$show_user_name = $current_game['use_name'];
	}
	$show_registration_link = 1;
	if (isset($current_game['use_login'])) {
		$show_registration_link = $current_game['use_login'];
	}
	?>
<div class="hidden_header">
    <div id="hidden_header_columns" class="hidden_header_columns_index">
         <div class="hidden_header_right_column hidden_header_right_column_index">    
        <dl>
            <?php if (empty($username)) :?>
            <?php endif; ?>
            <?php print_login($show_language_bar, $show_user_name, $show_registration_link); ?>
        </dl>    
        </div>
        <div style="clear:both;"></div>
    </div>
</div>
<?php 
	$clickable = true;
	if (empty($username) && !$show_language_bar) {
		$clickable = false;
	}
?>
<?php print_app_header_lower_part(false, $clickable);
}

/**
* Function to print saved simulations
* @return void
*/
function print_app_saved_games($user_games, $current_simulation) {
	
	global $language;
	global $image_folder;
	$db = DB::getInstance();
	$config = Config::getInstance();
	$current_game = $db->getGame($current_simulation, $language);
	$current_image_folder = '';
	if (isset($current_game['image_folder']) && !empty($current_game['image_folder'])) {
		$current_image_folder = $current_game['image_folder'];
	}
	else {
		$current_image_folder = $image_folder;
	}
	$current_image_folder = str_replace(array('/', '\\'), '/', $current_image_folder);
						
	if (!empty($user_games)) : ?>
			<hr />
			<div id="user_select_simulation_loading" class="result_loading"><img src="<?php echo($config->baseurl . 'img/loading.gif'); ?>" alt="<?php echo localize('IMAGE_ALT_LOADING'); ?>" /></div>
			<h3><?php echo localize('APP_GO_TO_SIMULATION'); ?>:</h3>
			<input type="hidden" name="user[settings][open_game][game_name]" id="user[settings][open_game][game_name]" value="<?php if(isset($_POST['user']['settings']['open_game']['game_name'])) echo($_POST['user']['settings']['open_game']['game_name']); ?>" />
			<div class="app_simulation_selection" id="user_simulation_selection_open_simulation">
<?php foreach($user_games as $game) {
			// Filter other games
			if ($game['game_id'] == $current_simulation) :
				$latest_played_card = end($db->getPlayedCards($game['profile_id']));
				$latest_card = $db->getCard($latest_played_card['card_id'], $language);
				$card_image = 'img/no-image.png';
				
				if(isset($latest_card['attachment'])) {
					if (!empty($latest_card['attachment'])) {
						$card_image = $current_image_folder . $latest_card['attachment'];
					}
				}
				$card_name = '&nbsp';
				if (isset($latest_card['card_name']) && !empty($latest_card['card_name'])) {
					$card_name = $latest_card['card_name'];
				}
				elseif (isset($latest_card['default_name'])) {
					$card_name = $latest_card['default_name'];
				}
?>
				<div id="user_select_simulation_<?php echo $game['profile_id']; ?>" class="<?php if($_POST['user']['settings']['open_game']['game_name'] == $game['profile_id']) : echo 'simulation_selected '; endif; if($game['game_ended']) : echo ' simulation_disabled '; endif; ?>simulation_select">
					<span class="left select_simulation_delete"></span>
					<span class="select_simulation_image"><img src="<?php echo($config->baseurl . $card_image); ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" /></span>
					<span class="select_simulation_center">
					<span>
					<?php echo(localize('APP_SIMULATION_STARTING_DATE') . ': ' . date(localize('DATE_FORMAT'), strtotime($game['profile_created']))); ?>
					</span>
					<?php if($game['game_ended']) : ?>
					<span class="right"><?php echo localize('APP_SIMULATION_OPEN_FINISHED')?></span>
					<?php endif;?>
					<br /><span><?php echo(localize('APP_SIMULATION_LATEST') . ': ' . $card_name) ?></span>
					</span>
					<span class="right select_simulation_start"></span>
				</div>
<?php 	endif;
		}
		unset($game);
?>
			</div>
<?php	if (isset($index_form_errors['user']['settings']['open_game']['game_name'])) : ?>
			<p class="error"><?php echo $index_form_errors['user']['settings']['open_game']['game_name']; ?></p>
<?php endif; ?>
			<br />
			<input type="submit" class="" id="user_open_game" name="user_open_game" value="<?php echo localize('OK'); ?>" />
<?php
	endif;
}

function print_app_delete_saved_game_modal() {
	?>
	<div id="delete_save_modal" class="jqmDialog jqmdWide">
		<a href="#" class="jqmClose" id="delete_save_modal_close"><?php echo localize('CLOSE'); ?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">
		
		<div class="jqmdMSG">
			<br />
			<br />
			<div class="centered largeText">
				<?php echo localize('APP_SIMULATION_CONFIRM_DELETE_SAVE')?>
			</div>
			<p><?php echo localize('APP_SIMULATION_CONFIRM_DELETE_SAVE_DESCRIPTION')?></p>
			<br />
			<div class="centered buttons">
				<input type="submit" class="jqmClose" id="delete_save_modal_yes_button" name="delete_save_modal_yes_button" value="<?php echo localize("YES"); ?>" />
				<input type="submit" class="jqmClose" id="delete_save_modal_no_button" name="delete_save_modal_no_button" value="<?php echo localize("NO"); ?>" />
			</div>
		</div>
		</div></div></div>
	</div>
	<?php
}
